#
# spec file for package python-fedmsg
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-fedmsg
Version:        1.1.1
Release:        bp153.1.21
Summary:        Fedora Messaging Client API
License:        LGPL-2.1-or-later
URL:            https://github.com/fedora-infra/fedmsg
# source from pypi is missing test fixtures
Source:         https://github.com/fedora-infra/fedmsg/archive/%{version}/fedmsg-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Sphinx
# SECTION tests
BuildRequires:  %{python_module SQLAlchemy}
BuildRequires:  %{python_module arrow}
BuildRequires:  %{python_module click}
BuildRequires:  %{python_module kitchen}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module moksha-hub}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pygments}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pyzmq}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module vcrpy}
BuildRequires:  gpg2
# /SECTION
Requires:       python-kitchen
Requires:       python-pyzmq
Requires:       python-requests
Requires:       python-six
Recommends:     python-arrow
Recommends:     python-M2Crypto
Recommends:     python-m2ext
Recommends:     python-cryptography >= 1.6
Recommends:     python-pyOpenSSL >= 16.1.0
Recommends:     python-Pygments
Recommends:     python-psutil
Recommends:     python-click
Recommends:     python-moksha.hub>=1.3.0
Recommends:     python-service_identity
BuildArch:      noarch

%python_subpackages

%description
fedmsg (Federated Message Bus) is a library built on ZeroMQ using the PyZMQ Python bindings.
fedmsg connects services together using ZeroMQ publishers and
subscribers.

%package        -n %{name}-doc
Summary:        Documentation for fedmsg

%description    -n %{name}-doc
This package contains the documentation for the fedmsg library and CLI programs.

%package        -n %{name}-base
Summary:        Base files system layout for packages using fedmsg
Supplements:    %{python_module %{name}}

%description    -n %{name}-base
This package contains the common filesystem layout shared by the python2 and
python3 versions of the fedmsg package.

%prep
%setup -q -n fedmsg-%{version}

%build
%python_build

export PYTHONPATH=$(pwd)
export PYTHON=python3
make -C doc SPHINXBUILD=sphinx-build html
rm doc/_build/html/.buildinfo
rm doc/_build/html/objects.inv

%check
%pytest fedmsg

%install
%python_install
%{python_expand # first remove the tests
rm -r %{buildroot}%{$python_sitelib}/fedmsg/tests/
%fdupes %{buildroot}%{$python_sitelib}
}
# system wide "config" files for fedmsg-base
mkdir -p %{buildroot}%{_sysconfdir}/fedmsg.d/
cp fedmsg.d/*.py %{buildroot}%{_sysconfdir}/fedmsg.d/.

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/*
%python3_only %{_bindir}/fedmsg-*

%files -n %{name}-doc
%license LICENSE
%doc README.rst doc/_build/html

%files -n %{name}-base
%license LICENSE
%doc README.rst
%dir %{_sysconfdir}/fedmsg.d/
%config(noreplace) %{_sysconfdir}/fedmsg.d/*

%changelog
* Tue Apr 28 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Mon Mar 25 2019 Jan Engelhardt <jengelh@inai.de>
- Trim filler wording from description.
* Mon Feb 11 2019 Dan Čermák <dcermak@suse.com>
- Split package into -doc, -base and py2 & py3 version
  * correct the source tarball (pypi tarball does not contain test fixtures)
  * use py.test to run the tests as upstream does
  * install the common "config" files to /etc/fedmsg.d/ where fedmsg expects them
  * build and install the documentation
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Mar 21 2018 sebix+novell.com@sebix.at
- update to version 1.1.1
  * Fix a bug in the configuration validation for crl_cache_expiry and ca_cert_cache_expiry (#500).
* Tue Feb  6 2018 sebix+novell.com@sebix.at
- initial package for version 1.1.0
